=========================
StatsDict: Save Run Stats
=========================
.. badges-begin

| |PyPi| |Python Version| |Repo| |Downloads| |Dlrate|
| |License| |Tests| |Coverage| |Codacy| |Issues| |Health|

.. |PyPI| image:: https://img.shields.io/pypi/v/statsdict.svg
   :target: https://pypi.org/project/statsdict/
   :alt: PyPI package
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/statsdict
   :target: https://pypi.org/project/statsdict
   :alt: Supported Python Versions
.. |Repo| image:: https://img.shields.io/github/last-commit/hydrationdynamics/statsdict
    :target: https://github.com/hydrationdynamics/statsdict
    :alt: GitHub repository
.. |Downloads| image:: https://pepy.tech/badge/statsdict
     :target: https://pepy.tech/project/statsdict
     :alt: Download stats
.. |Dlrate| image:: https://img.shields.io/pypi/dm/statsdict
   :target: https://github.com/hydrationdynamics/statsdict
   :alt: PYPI download rate
.. |License| image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
    :target: https://github.com/hydrationdynamics/statsdict/blob/master/LICENSE.txt
    :alt: License terms
.. |Tests| image:: https://github.com/hydrationdynamics/statsdict/workflows/Tests/badge.svg
   :target: https://github.com/hydrationdynamics/statsdict/actions?workflow=Tests
   :alt: Tests
.. |Coverage| image:: https://codecov.io/gh/hydrationdynamics/statsdict/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/hydrationdynamics/statsdict
    :alt: Codecov.io test coverage
.. |Codacy| image:: https://api.codacy.com/project/badge/Grade/d9c8687d3c544049a293b2faf8919c07
    :target: https://www.codacy.com/gh/hydrationdynamics/statsdict?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=hydrationdynamics/statsdict&amp;utm_campaign=Badge_Grade
    :alt: Codacy.io grade
.. |Issues| image:: https://img.shields.io/github/issues/hydrationdynamics/statsdict.svg
    :target:  https://github.com/hydrationdynamics/statsdict/issues
    :alt: Issues reported
.. |Read the Docs| image:: https://img.shields.io/readthedocs/statsdict/latest.svg?label=Read%20the%20Docs
   :target: https://statsdict.readthedocs.io/
   :alt: Read the documentation at https://statsdict.readthedocs.io/
.. |Health| image:: https://snyk.io/advisor/python/statsdict/badge.svg
  :target: https://snyk.io/advisor/python/statsdict
  :alt: Snyk health

.. badges-end

.. image:: https://raw.githubusercontent.com/hydrationdynamics/statsdict/main/docs/_static/logo.png
   :target: https://raw.githubusercontent.com/hydrationdynamics/statsdict/main/LICENSE.artwork.txt
   :alt: Fly StatsDict logo

.. |Codecov| image:: https://codecov.io/gh/hydrationdynamics/statsdict/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/hydrationdynamics/statsdict
   :alt: Codecov

Features
--------

* Save global run statistics to a JSON file suitable for use with a web service.


Requirements
------------

* Tested on Python 3.8 to 3.10 on Linux and Mac


Installation
------------

You can install *StatsDict* via pip_ from PyPI_:

.. code:: console

   $ pip install statsdict


Usage
-----

Please see the `Command-line Reference <Usage_>`_ for details.


Contributing
------------

Contributions are very welcome.
To learn more, see the `Contributor Guide`_.


License
-------

Distributed under the terms of the `BSD 3-Clause license`_,
*StatsDict* is free and open source software.


Issues
------

If you encounter any problems,
please `file an issue`_ along with a detailed description.


Credits
-------

StatsDict was written by Joel Berendzen.


.. _BSD 3-Clause license: https://opensource.org/licenses/BSD-3-Clause
.. _PyPI: https://pypi.org/
.. _file an issue: https://github.com/joelb123/statsdict/issues
.. _pip: https://pip.pypa.io/
.. github-only
.. _Contributor Guide: CONTRIBUTING.rst
.. _Usage: https://statsdict.readthedocs.io/en/latest/usage.html
